@@ -3,7 +3,6 @@ package main
 import (
 	"bytes"
 	"context"
-	"encoding/json"
 	"fmt"
 	"io"
 	"os"
@@ -50,18 +49,22 @@ type hclRunDiff struct {
 }
 
 func addRunFlags(cmd *cobra.Command) {
-	cmd.Flags().Bool("terraform-parse-hcl", false, "Parse HCL code instead of generating a Terraform plan. This does not need credentials and is faster (experimental)")
-	cmd.Flags().StringSlice("terraform-var-file", nil, "Load variable files, similar to Terraform’s -var-file flag. Applicable with --terraform-parse-hcl (experimental)")
-	cmd.Flags().StringSlice("terraform-var", nil, "Set value for an input variable, similar to Terraform’s -var flag. Applicable with --terraform-parse-hcl (experimental)")
+	cmd.Flags().StringSlice("terraform-var-file", nil, "Load variable files, similar to Terraform's -var-file flag. Provided files must be relative to the --path flag")
+	cmd.Flags().StringSlice("terraform-var", nil, "Set value for an input variable, similar to Terraform's -var flag")
 	cmd.Flags().StringP("path", "p", "", "Path to the Terraform directory or JSON/plan file")
 
 	cmd.Flags().String("config-file", "", "Path to Infracost config file. Cannot be used with path, terraform* or usage-file flags")
 	cmd.Flags().String("usage-file", "", "Path to Infracost usage file that specifies values for usage-based resources")
 
-	cmd.Flags().String("terraform-plan-flags", "", "Flags to pass to 'terraform plan'. Applicable when path is a Terraform directory")
-	cmd.Flags().String("terraform-init-flags", "", "Flags to pass to 'terraform init'. Applicable when path is a Terraform directory")
+	cmd.Flags().String("project-name", "", "Name of project in the output. Defaults to path or git repo name")
+
+	cmd.Flags().Bool("terraform-force-cli", false, "Generate the Terraform plan JSON using the Terraform CLI. This may require cloud credentials")
+	cmd.Flags().String("terraform-plan-flags", "", "Flags to pass to 'terraform plan'. Applicable with --terraform-force-cli")
+	cmd.Flags().String("terraform-init-flags", "", "Flags to pass to 'terraform init'. Applicable with --terraform-force-cli")
 	cmd.Flags().String("terraform-workspace", "", "Terraform workspace to use. Applicable when path is a Terraform directory")
 
+	cmd.Flags().StringSlice("exclude-path", nil, "Paths of directories to exclude, glob patterns need quotes")
+
 	cmd.Flags().Bool("no-cache", false, "Don't attempt to cache Terraform plans")
 
 	cmd.Flags().Bool("show-skipped", false, "List unsupported and free resources")
@@ -71,6 +74,11 @@ func addRunFlags(cmd *cobra.Command) {
 	_ = cmd.MarkFlagFilename("path", "json", "tf")
 	_ = cmd.MarkFlagFilename("config-file", "yml")
 	_ = cmd.MarkFlagFilename("usage-file", "yml")
+
+	_ = cmd.Flags().MarkHidden("terraform-force-cli")
+	// These are deprecated and will show a warning if used without --terraform-force-cli
+	_ = cmd.Flags().MarkHidden("terraform-plan-flags")
+	_ = cmd.Flags().MarkHidden("terraform-init-flags")
 }
 
 // panicError is used to collect goroutine panics into an error interface so
@@ -84,35 +92,8 @@ func (p *panicError) Error() string {
 }
 
 func runMain(cmd *cobra.Command, runCtx *config.RunContext) error {
-	if runCtx.Config.IsSelfHosted() && runCtx.Config.EnableDashboard {
-		ui.PrintWarning(cmd.ErrOrStderr(), "The dashboard is part of Infracost's hosted services. Contact hello@infracost.io for help.")
-	}
-
-	parallelism, err := getParallelism(cmd, runCtx)
-	if err != nil {
-		return err
-	}
-	runCtx.SetContextValue("parallelism", parallelism)
-
-	numJobs := len(runCtx.Config.Projects)
-	jobs := make(chan projectJob, numJobs)
-
-	projectResultChan := make(chan projectResult, numJobs)
-	errGroup, _ := errgroup.WithContext(context.Background())
-
-	runInParallel := parallelism > 1 && numJobs > 1
-	if (runInParallel || runCtx.IsCIRun()) && !runCtx.Config.IsLogging() {
-		if runInParallel {
-			cmd.PrintErrln("Running multiple projects in parallel, so log-level=info is enabled by default.")
-			cmd.PrintErrln("Run with INFRACOST_PARALLELISM=1 to disable parallelism to help debugging.")
-			cmd.PrintErrln()
-		}
-
-		runCtx.Config.LogLevel = "info"
-		err := runCtx.Config.ConfigureLogger()
-		if err != nil {
-			return err
-		}
+	if runCtx.Config.IsSelfHosted() && runCtx.Config.IsCloudEnabled() {
+		ui.PrintWarning(cmd.ErrOrStderr(), "Infracost Cloud is part of Infracost's hosted services. Contact hello@infracost.io for help.")
 	}
 
 	pr, err := newParallelRunner(cmd, runCtx)
@@ -120,56 +101,11 @@ func runMain(cmd *cobra.Command, runCtx *config.RunContext) error {
 		return err
 	}
 
-	for i := 0; i < parallelism; i++ {
-		errGroup.Go(func() (err error) {
-			// defer a function to recover from any panics spawned by child goroutines.
-			// This is done as recover works only in the same goroutine that it is called.
-			// We need to catch any child goroutine panics and hand them up to the main caller
-			// so that it can be caught and displayed correctly to the user.
-			defer func() {
-				e := recover()
-				if e != nil {
-					err = &panicError{msg: fmt.Sprintf("%s\n%s", e, debug.Stack())}
-				}
-			}()
-
-			for job := range jobs {
-				ctx := config.NewProjectContext(runCtx, job.projectCfg)
-				configProjects, err := pr.runProjectConfig(ctx)
-				if err != nil {
-					return err
-				}
-
-				projectResultChan <- projectResult{
-					index:      job.index,
-					ctx:        ctx,
-					projectOut: configProjects,
-				}
-			}
-
-			return nil
-		})
-	}
-
-	for i, p := range runCtx.Config.Projects {
-		jobs <- projectJob{index: i, projectCfg: p}
-	}
-	close(jobs)
-
-	err = errGroup.Wait()
+	projectResults, err := pr.run()
 	if err != nil {
 		return err
 	}
 
-	close(projectResultChan)
-	projectResults := make([]projectResult, 0, len(runCtx.Config.Projects))
-	for result := range projectResultChan {
-		projectResults = append(projectResults, result)
-	}
-	sort.Slice(projectResults, func(i, j int) bool {
-		return projectResults[i].index < projectResults[j].index
-	})
-
 	projects := make([]*schema.Project, 0)
 	projectContexts := make([]*config.ProjectContext, 0)
 
@@ -191,6 +127,10 @@ func runMain(cmd *cobra.Command, runCtx *config.RunContext) error {
 		go formatHCLProjects(wg, runCtx, hclProjects, hclR)
 	}
 
+	for _, project := range projects {
+		project.Metadata.InfracostCommand = cmd.Name()
+	}
+
 	r, err := output.ToOutputFormat(projects)
 	if err != nil {
 		return err
@@ -215,36 +155,23 @@ func runMain(cmd *cobra.Command, runCtx *config.RunContext) error {
 
 	r.RunID, r.ShareURL = result.RunID, result.ShareURL
 
-	opts := output.Options{
-		DashboardEnabled: runCtx.Config.EnableDashboard,
-		ShowSkipped:      runCtx.Config.ShowSkipped,
-		NoColor:          runCtx.Config.NoColor,
-		Fields:           runCtx.Config.Fields,
-	}
-
-	var b []byte
-
 	format := strings.ToLower(runCtx.Config.Format)
-	if runCtx.Config.CompareTo != "" && !validCompareToFormats[format] {
+	isCompareRun := runCtx.Config.CompareTo != ""
+	if isCompareRun && !validCompareToFormats[format] {
 		return errors.New("The --compare-to option cannot be used with table and html formats as they output breakdowns, specify a different --format.")
 	}
 
-	switch format {
-	case "json":
-		b, err = output.ToJSON(r, opts)
-	case "html":
-		b, err = output.ToHTML(r, opts)
-	case "diff":
-		b, err = output.ToDiff(r, opts)
-	default:
-		b, err = output.ToTable(r, opts)
-	}
-
+	b, err := output.FormatOutput(format, r, output.Options{
+		DashboardEnabled: runCtx.Config.IsCloudEnabled(),
+		ShowSkipped:      runCtx.Config.ShowSkipped,
+		NoColor:          runCtx.Config.NoColor,
+		Fields:           runCtx.Config.Fields,
+	})
 	if err != nil {
-		return errors.Wrap(err, "Error generating output")
+		return err
 	}
 
-	if runCtx.Config.Format == "diff" || runCtx.Config.Format == "table" {
+	if format == "diff" || format == "table" {
 		lines := bytes.Count(b, []byte("\n")) + 1
 		runCtx.SetContextValue("lineCount", lines)
 	}
@@ -273,37 +200,13 @@ func runMain(cmd *cobra.Command, runCtx *config.RunContext) error {
 	return nil
 }
 
-func loadInfracostJSONSnapshot(snapshot string) (output.Root, error) {
-	_, err := os.Stat(snapshot)
-	if errors.Is(err, os.ErrNotExist) {
-		return output.Root{}, fmt.Errorf("%s used by --compare-to flag does not exist", snapshot)
-	}
-
-	if err != nil {
-		return output.Root{}, fmt.Errorf("Could not load %s used by --compare-to flag, err: %s", snapshot, err)
-	}
-
-	b, err := os.ReadFile(snapshot)
-	if err != nil {
-		return output.Root{}, fmt.Errorf("Could not read %s used by --compare-to flag, err: %s", snapshot, err)
-	}
-
-	var prior output.Root
-	err = json.Unmarshal(b, &prior)
-	if err != nil {
-		return output.Root{}, fmt.Errorf("Could not decode file %s used by compare-to flag, please ensure it is a valid Infracost JSON", snapshot)
-	}
-
-	return prior, nil
-}
-
 func formatHCLProjects(wg *sync.WaitGroup, ctx *config.RunContext, hclProjects []*schema.Project, hclR *output.Root) {
 	defer func() {
 		err := recover()
 		wg.Done()
 
 		if err != nil {
-			err = apiclient.ReportCLIError(ctx, fmt.Errorf("hcl-runtime-error: formatting hcl projects %s\n%s", err, debug.Stack()))
+			err = apiclient.ReportCLIError(ctx, fmt.Errorf("hcl-runtime-error: formatting hcl projects %s\n%s", err, debug.Stack()), false)
 			if err != nil {
 				log.Debugf("error reporting unexpected hcl runtime error: %s", err)
 			}
@@ -324,10 +227,12 @@ type projectOutput struct {
 }
 
 type parallelRunner struct {
-	cmd      *cobra.Command
-	runCtx   *config.RunContext
-	pathMuxs map[string]*sync.Mutex
-	prior    *output.Root
+	cmd         *cobra.Command
+	runCtx      *config.RunContext
+	pathMuxs    map[string]*sync.Mutex
+	prior       *output.Root
+	parallelism int
+	numJobs     int
 }
 
 func newParallelRunner(cmd *cobra.Command, runCtx *config.RunContext) (*parallelRunner, error) {
@@ -341,22 +246,107 @@ func newParallelRunner(cmd *cobra.Command, runCtx *config.RunContext) (*parallel
 
 	var prior *output.Root
 	if runCtx.Config.CompareTo != "" {
-		snapshot, err := loadInfracostJSONSnapshot(runCtx.Config.CompareTo)
+		snapshot, err := output.Load(runCtx.Config.CompareTo)
 		if err != nil {
-			return nil, err
+			return nil, fmt.Errorf("Error loading %s used by --compare-to flag. %s", runCtx.Config.CompareTo, err)
 		}
 
 		prior = &snapshot
 	}
 
+	parallelism, err := getParallelism(cmd, runCtx)
+	if err != nil {
+		return nil, err
+	}
+	runCtx.SetContextValue("parallelism", parallelism)
+
+	numJobs := len(runCtx.Config.Projects)
+
+	runInParallel := parallelism > 1 && numJobs > 1
+	if (runInParallel || runCtx.IsCIRun()) && !runCtx.Config.IsLogging() {
+		if runInParallel {
+			cmd.PrintErrln("Running multiple projects in parallel, so log-level=info is enabled by default.")
+			cmd.PrintErrln("Run with INFRACOST_PARALLELISM=1 to disable parallelism to help debugging.")
+			cmd.PrintErrln()
+		}
+
+		runCtx.Config.LogLevel = "info"
+		err := runCtx.Config.ConfigureLogger()
+		if err != nil {
+			return nil, err
+		}
+	}
+
 	return &parallelRunner{
-		runCtx:   runCtx,
-		cmd:      cmd,
-		pathMuxs: pathMuxs,
-		prior:    prior,
+		parallelism: parallelism,
+		numJobs:     numJobs,
+		runCtx:      runCtx,
+		cmd:         cmd,
+		pathMuxs:    pathMuxs,
+		prior:       prior,
 	}, nil
 }
 
+func (r *parallelRunner) run() ([]projectResult, error) {
+	projectResultChan := make(chan projectResult, r.numJobs)
+	jobs := make(chan projectJob, r.numJobs)
+
+	errGroup, _ := errgroup.WithContext(context.Background())
+	for i := 0; i < r.parallelism; i++ {
+		errGroup.Go(func() (err error) {
+			// defer a function to recover from any panics spawned by child goroutines.
+			// This is done as recover works only in the same goroutine that it is called.
+			// We need to catch any child goroutine panics and hand them up to the main caller
+			// so that it can be caught and displayed correctly to the user.
+			defer func() {
+				e := recover()
+				if e != nil {
+					err = &panicError{msg: fmt.Sprintf("%s\n%s", e, debug.Stack())}
+				}
+			}()
+
+			for job := range jobs {
+				ctx := config.NewProjectContext(r.runCtx, job.projectCfg)
+				configProjects, err := r.runProjectConfig(ctx)
+				if err != nil {
+					return err
+				}
+
+				projectResultChan <- projectResult{
+					index:      job.index,
+					ctx:        ctx,
+					projectOut: configProjects,
+				}
+			}
+
+			return nil
+		})
+	}
+
+	for i, p := range r.runCtx.Config.Projects {
+		jobs <- projectJob{index: i, projectCfg: p}
+	}
+	close(jobs)
+
+	err := errGroup.Wait()
+	if err != nil {
+		return nil, err
+	}
+
+	close(projectResultChan)
+
+	projectResults := make([]projectResult, 0, len(r.runCtx.Config.Projects))
+	for result := range projectResultChan {
+		projectResults = append(projectResults, result)
+	}
+
+	sort.Slice(projectResults, func(i, j int) bool {
+		return projectResults[i].index < projectResults[j].index
+	})
+
+	return projectResults, nil
+}
+
 func (r *parallelRunner) runProjectConfig(ctx *config.ProjectContext) (*projectOutput, error) {
 	mux := r.pathMuxs[ctx.ProjectConfig.Path]
 	if mux != nil {
@@ -381,6 +371,13 @@ func (r *parallelRunner) runProjectConfig(ctx *config.ProjectContext) (*projectO
 
 	ctx.SetContextValue("projectType", provider.Type())
 
+	projectTypes := []interface{}{}
+	if t, ok := ctx.RunContext.ContextValues()["projectTypes"]; ok {
+		projectTypes = t.([]interface{})
+	}
+	projectTypes = append(projectTypes, provider.Type())
+	ctx.RunContext.SetContextValue("projectTypes", projectTypes)
+
 	if r.cmd.Name() == "diff" && provider.Type() == "terraform_state_json" {
 		m := "Cannot use Terraform state JSON with the infracost diff command.\n\n"
 		m += fmt.Sprintf("Use the %s flag to specify the path to one of the following:\n", ui.PrimaryString("--path"))
@@ -389,6 +386,10 @@ func (r *parallelRunner) runProjectConfig(ctx *config.ProjectContext) (*projectO
 	}
 
 	m := fmt.Sprintf("Detected %s at %s", provider.DisplayType(), ui.DisplayPath(ctx.ProjectConfig.Path))
+	if provider.Type() == "terraform_dir" {
+		m = fmt.Sprintf("Evaluating %s at %s", provider.DisplayType(), ui.DisplayPath(ctx.ProjectConfig.Path))
+	}
+
 	if r.runCtx.Config.IsLogging() {
 		log.Info(m)
 	} else {
@@ -490,14 +491,18 @@ func (r *parallelRunner) runProjectConfig(ctx *config.ProjectContext) (*projectO
 			r.cmd.PrintErrln()
 
 			if e := unwrapped(err); errors.Is(e, apiclient.ErrInvalidAPIKey) {
-				return nil, fmt.Errorf("%v\n%s %s %s %s %s\n%s",
+				return nil, fmt.Errorf("%v\n%s %s %s %s %s\n%s %s.\n%s %s %s",
 					e.Error(),
 					"Please check your",
 					ui.PrimaryString(config.CredentialsFilePath()),
 					"file or",
 					ui.PrimaryString("INFRACOST_API_KEY"),
 					"environment variable.",
-					"If you continue having issues please email hello@infracost.io",
+					"If you recently regenerated your API key, you can retrieve it from",
+					ui.PrimaryString(r.runCtx.Config.DashboardEndpoint),
+					"See",
+					ui.PrimaryString("https://infracost.io/support"),
+					"if you continue having issues.",
 				)
 			}
 
@@ -537,7 +542,7 @@ func (r *parallelRunner) runHCLProvider(wg *sync.WaitGroup, ctx *config.ProjectC
 
 		if err != nil {
 			log.Debugf("recovered from hcl provider panic %s", err)
-			err = apiclient.ReportCLIError(r.runCtx, fmt.Errorf("hcl-runtime-error: loading resources %s\n%s", err, debug.Stack()))
+			err = apiclient.ReportCLIError(r.runCtx, fmt.Errorf("hcl-runtime-error: loading resources %s\n%s", err, debug.Stack()), false)
 			if err != nil {
 				log.Debugf("error reporting unexpected hcl runtime error: %s", err)
 			}
@@ -549,7 +554,7 @@ func (r *parallelRunner) runHCLProvider(wg *sync.WaitGroup, ctx *config.ProjectC
 
 	t1 := time.Now()
 
-	hclProvider, err := terraform.NewHCLProvider(ctx, terraform.NewPlanJSONProvider(ctx, r.prior == nil))
+	hclProvider, err := terraform.NewHCLProvider(ctx, &terraform.HCLProviderConfig{SuppressLogging: true})
 	if err != nil {
 		log.Debugf("Could not init HCL provider: %s", err)
 		return
@@ -698,6 +703,7 @@ func loadRunFlags(cfg *config.Config, cmd *cobra.Command) error {
 
 	hasProjectFlags := (hasPathFlag ||
 		cmd.Flags().Changed("usage-file") ||
+		cmd.Flags().Changed("project-name") ||
 		cmd.Flags().Changed("terraform-plan-flags") ||
 		cmd.Flags().Changed("terraform-var-file") ||
 		cmd.Flags().Changed("terraform-var") ||
@@ -707,7 +713,7 @@ func loadRunFlags(cfg *config.Config, cmd *cobra.Command) error {
 
 	if hasConfigFile && hasProjectFlags {
 		m := "--config-file flag cannot be used with the following flags: "
-		m += "--path, --terraform-*, --usage-file"
+		m += "--path, --project-name, --terraform-*, --usage-file"
 		ui.PrintUsage(cmd)
 		return errors.New(m)
 	}
@@ -716,14 +722,16 @@ func loadRunFlags(cfg *config.Config, cmd *cobra.Command) error {
 
 	if hasProjectFlags {
 		projectCfg.Path, _ = cmd.Flags().GetString("path")
-		projectCfg.TerraformParseHCL, _ = cmd.Flags().GetBool("terraform-parse-hcl")
 		projectCfg.TerraformVarFiles, _ = cmd.Flags().GetStringSlice("terraform-var-file")
 		tfVars, _ := cmd.Flags().GetStringSlice("terraform-var")
 		projectCfg.TerraformVars = tfVarsToMap(tfVars)
 		projectCfg.UsageFile, _ = cmd.Flags().GetString("usage-file")
+		projectCfg.Name, _ = cmd.Flags().GetString("project-name")
+		projectCfg.TerraformForceCLI, _ = cmd.Flags().GetBool("terraform-force-cli")
 		projectCfg.TerraformPlanFlags, _ = cmd.Flags().GetString("terraform-plan-flags")
 		projectCfg.TerraformInitFlags, _ = cmd.Flags().GetString("terraform-init-flags")
 		projectCfg.TerraformUseState, _ = cmd.Flags().GetBool("terraform-use-state")
+		projectCfg.ExcludePaths, _ = cmd.Flags().GetStringSlice("exclude-path")
 
 		if cmd.Flags().Changed("terraform-workspace") {
 			projectCfg.TerraformWorkspace, _ = cmd.Flags().GetString("terraform-workspace")
@@ -738,9 +746,11 @@ func loadRunFlags(cfg *config.Config, cmd *cobra.Command) error {
 			return err
 		}
 
-		if parseHCL, _ := cmd.Flags().GetBool("terraform-parse-hcl"); parseHCL {
+		cfg.ConfigFilePath = cfgFilePath
+
+		if forceCLI, _ := cmd.Flags().GetBool("terraform-force-cli"); forceCLI {
 			for _, p := range cfg.Projects {
-				p.TerraformParseHCL = true
+				p.TerraformForceCLI = true
 			}
 		}
 	}
