@@ -14,7 +14,7 @@ import (
 
 type DashboardAPIClient struct {
 	APIClient
-	dashboardEnabled bool
+	shouldStoreRun bool
 }
 
 type CreateAPIKeyResponse struct {
@@ -51,15 +51,14 @@ func NewDashboardAPIClient(ctx *config.RunContext) *DashboardAPIClient {
 			apiKey:   ctx.Config.APIKey,
 			uuid:     ctx.UUID(),
 		},
-		dashboardEnabled: ctx.Config.EnableDashboard && !ctx.Config.IsSelfHosted(),
+		shouldStoreRun: ctx.Config.IsCloudEnabled() && !ctx.Config.IsSelfHosted(),
 	}
 }
 
-func (c *DashboardAPIClient) CreateAPIKey(name string, email string, ciInterest bool, contextVals map[string]interface{}) (CreateAPIKeyResponse, error) {
+func (c *DashboardAPIClient) CreateAPIKey(name string, email string, contextVals map[string]interface{}) (CreateAPIKeyResponse, error) {
 	d := map[string]interface{}{
 		"name":        name,
 		"email":       email,
-		"ci":          ciInterest,
 		"os":          contextVals["os"],
 		"version":     contextVals["version"],
 		"fullVersion": contextVals["fullVersion"],
@@ -81,8 +80,8 @@ func (c *DashboardAPIClient) CreateAPIKey(name string, email string, ciInterest
 func (c *DashboardAPIClient) AddRun(ctx *config.RunContext, projectContexts []*config.ProjectContext, out output.Root) (AddRunResponse, error) {
 	response := AddRunResponse{}
 
-	if !c.dashboardEnabled {
-		log.Debug("Skipping sending project results to your dashboard since it is not enabled. Run 'infracost configure set enable_dashboard true' to enable it.")
+	if !c.shouldStoreRun {
+		log.Debug("Skipping sending project results since it is disabled.")
 		return response, nil
 	}
 
@@ -103,7 +102,7 @@ func (c *DashboardAPIClient) AddRun(ctx *config.RunContext, projectContexts []*c
 		"run": runInput{
 			ProjectResults: projectResultInputs,
 			Currency:       out.Currency,
-			TimeGenerated:  out.TimeGenerated,
+			TimeGenerated:  out.TimeGenerated.UTC(),
 			Metadata:       ctx.ContextValues(),
 		},
 	}
