@@ -108,17 +108,6 @@ func convertCostComponents(outComponents []CostComponent) []*schema.CostComponen
 
 type Projects []Project
 
-// ToMap returns the project list as a lookup map, which can be used to find the same project across multiple runs.
-func (projects Projects) ToMap() map[string]Project {
-	m := make(map[string]Project)
-
-	for _, p := range projects {
-		m[p.Name] = p
-	}
-
-	return m
-}
-
 var exampleProjectsRegex = regexp.MustCompile(`^infracost\/(infracost\/examples|example-terraform)\/`)
 
 func (r *Root) ExampleProjectName() string {
@@ -135,11 +124,27 @@ func (r *Root) ExampleProjectName() string {
 	return r.Projects[0].Name
 }
 
-func (p *Project) Label(dashboardEnabled bool) string {
-	if !dashboardEnabled {
+// Label returns the display name of the project
+func (p *Project) Label() string {
+	return p.Name
+}
+
+// LabelWithMetadata returns the display name of the project appended with any distinguishing
+// metadata (Module path or Workspace)
+func (p *Project) LabelWithMetadata() string {
+	metadataInfo := []string{}
+	if p.Metadata.TerraformModulePath != "" {
+		metadataInfo = append(metadataInfo, "Module path: "+p.Metadata.TerraformModulePath)
+	}
+	if p.Metadata.WorkspaceLabel() != "" {
+		metadataInfo = append(metadataInfo, "Workspace: "+p.Metadata.WorkspaceLabel())
+	}
+
+	if len(metadataInfo) == 0 {
 		return p.Name
 	}
-	return fmt.Sprintf("%s (%s)", p.Name, p.Metadata.Path)
+
+	return fmt.Sprintf("%s (%s)", p.Name, strings.Join(metadataInfo, ", "))
 }
 
 type Breakdown struct {
@@ -159,13 +164,13 @@ type CostComponent struct {
 }
 
 type Resource struct {
-	Name           string            `json:"name"`
-	Tags           map[string]string `json:"tags,omitempty"`
-	Metadata       map[string]string `json:"metadata"`
-	HourlyCost     *decimal.Decimal  `json:"hourlyCost"`
-	MonthlyCost    *decimal.Decimal  `json:"monthlyCost"`
-	CostComponents []CostComponent   `json:"costComponents,omitempty"`
-	SubResources   []Resource        `json:"subresources,omitempty"`
+	Name           string                 `json:"name"`
+	Tags           map[string]string      `json:"tags,omitempty"`
+	Metadata       map[string]interface{} `json:"metadata"`
+	HourlyCost     *decimal.Decimal       `json:"hourlyCost"`
+	MonthlyCost    *decimal.Decimal       `json:"monthlyCost"`
+	CostComponents []CostComponent        `json:"costComponents,omitempty"`
+	SubResources   []Resource             `json:"subresources,omitempty"`
 }
 
 func (r Resource) ResourceType() string {
@@ -288,9 +293,16 @@ func outputResource(r *schema.Resource) Resource {
 		subresources = append(subresources, outputResource(s))
 	}
 
+	metadata := make(map[string]interface{})
+	if r.Metadata != nil {
+		for k, v := range r.Metadata {
+			metadata[k] = v.Value()
+		}
+	}
+
 	return Resource{
 		Name:           r.Name,
-		Metadata:       map[string]string{},
+		Metadata:       metadata,
 		Tags:           r.Tags,
 		HourlyCost:     r.HourlyCost,
 		MonthlyCost:    r.MonthlyCost,
@@ -408,7 +420,7 @@ func ToOutputFormat(projects []*schema.Project) (Root, error) {
 		PastTotalMonthlyCost: pastTotalMonthlyCost,
 		DiffTotalHourlyCost:  diffTotalHourlyCost,
 		DiffTotalMonthlyCost: diffTotalMonthlyCost,
-		TimeGenerated:        time.Now(),
+		TimeGenerated:        time.Now().UTC(),
 		Summary:              MergeSummaries(summaries),
 		FullSummary:          MergeSummaries(fullSummaries),
 	}
@@ -713,7 +725,7 @@ func sortResources(resources []Resource, groupKey string) {
 		}
 
 		// Sort by the group key
-		return resources[i].Metadata[groupKey] < resources[j].Metadata[groupKey]
+		return resources[i].Metadata[groupKey].(string) < resources[j].Metadata[groupKey].(string)
 	})
 }
 
