@@ -32,11 +32,11 @@ func NewPlanProvider(ctx *config.ProjectContext, includePastResources bool) sche
 }
 
 func (p *PlanProvider) Type() string {
-	return "terraform_plan"
+	return "terraform_plan_binary"
 }
 
 func (p *PlanProvider) DisplayType() string {
-	return "Terraform plan file"
+	return "Terraform plan binary file"
 }
 
 func (p *PlanProvider) LoadResources(usage map[string]*schema.UsageData) ([]*schema.Project, error) {
@@ -55,7 +55,7 @@ func (p *PlanProvider) LoadResources(usage map[string]*schema.UsageData) ([]*sch
 	metadata := config.DetectProjectMetadata(p.ctx.ProjectConfig.Path)
 	metadata.Type = p.Type()
 	p.AddMetadata(metadata)
-	name := schema.GenerateProjectName(metadata, p.ctx.RunContext.Config.EnableDashboard)
+	name := schema.GenerateProjectName(metadata, p.ctx.ProjectConfig.Name, p.ctx.RunContext.Config.IsCloudEnabled())
 
 	project := schema.NewProject(name, metadata)
 	parser := NewParser(p.ctx, p.includePastResources)
