@@ -395,7 +395,7 @@ func newHCLProvider(t *testing.T, runCtx *config.RunContext, tfdir string) *terr
 		},
 	)
 
-	provider, err := terraform.NewHCLProvider(projectCtx, terraform.NewPlanJSONProvider(projectCtx, true))
+	provider, err := terraform.NewHCLProvider(projectCtx, &terraform.HCLProviderConfig{SuppressLogging: true})
 	require.NoError(t, err)
 
 	return provider
@@ -410,7 +410,7 @@ func createTerraformProject(t *testing.T, tfProject TerraformProject) string {
 		err := copyInitCacheToPath(initCache, tmpDir)
 		require.NoError(t, err)
 	} else {
-		t.Log(fmt.Sprintf("Couldn't copy terraform init cache from %s", initCache))
+		t.Logf("Couldn't copy terraform init cache from %s", initCache)
 	}
 
 	tfdir, err := CreateTerraformProject(tmpDir, tfProject)
