@@ -14,6 +14,7 @@ type ComputeRegionInstanceGroupManager struct {
 	MachineType       string
 	PurchaseOption    string
 	TargetSize        int64
+	ScratchDisks      int
 	Disks             []*ComputeDisk
 	GuestAccelerators []*ComputeGuestAccelerator
 }
@@ -39,6 +40,10 @@ func (r *ComputeRegionInstanceGroupManager) BuildResource() *schema.Resource {
 		costComponents = append(costComponents, computeDiskCostComponent(r.Region, disk.Type, disk.Size, r.TargetSize))
 	}
 
+	if r.ScratchDisks > 0 {
+		costComponents = append(costComponents, scratchDiskCostComponent(r.Region, r.PurchaseOption, r.ScratchDisks*int(r.TargetSize)))
+	}
+
 	for _, guestAccel := range r.GuestAccelerators {
 		costComponents = append(costComponents, guestAcceleratorCostComponent(r.Region, r.PurchaseOption, guestAccel.Type, guestAccel.Count, r.TargetSize))
 	}
